@@ -12,8 +12,12 @@ data1 <- ggplot2::diamonds %>%
 data2 <- simplevis::example_sf_point %>% 
   mutate(trend_category = factor(trend_category, levels = c("Improving", "Indeterminate", "Worsening")))
 
-# add helper vectors (if required)
-color_vector <- sort(unique(data1$color))
+# add reference
+data_source <- "Diamonds Association"
 
-# choose a basemap (if required)
+# choose a basemap 
 basemap <- leaflet_basemap(bounds = c(166.70047,-34.45676, 178.52966,-47.06345))
+
+# add other helpers as required
+color_vector <- sort(unique(data1$color))
+title_wrap <- 50
\ No newline at end of file
