@@ -10,68 +10,73 @@ shinyServer(function(input, output, session) {
     # add plot_data code from make_data_vis.R
     # change any placeholder character values to input widgets
     
-    selected_color <- input$plot_color
-    
+    .color <- input$plot_color
+
     plot_data <- data %>%
-      filter(color == selected_color) %>% 
+      filter(color == .color) %>% 
       mutate(cut = stringr::str_to_sentence(cut)) %>%
       group_by(cut, clarity, .drop = FALSE) %>%
-      summarise(average_price = round(mean(price), 0)) %>%
-      mutate(average_price_thousands = round(average_price / 1000, 1)) %>%
-      mutate(average_price = paste0("US$", prettyNum(average_price,  big.mark = ","))) %>% 
-      mutate_text(c("cut", "clarity", "average_price"))
+      summarise(price = round(mean(price), 2)) %>%
+      mutate_text(c("cut", "clarity", "price")) 
     
     return(plot_data)
-  })
+  }) #%>% 
+    # bindCache(input$plot_color)
   
+  output$plot_data <- DT::renderDT(plot_data(), filter = "top", rownames = FALSE, 
+                                   options = list(pageLength = 5, scrollX = TRUE))
+
   plot <- reactive({ # create a reactive ggplot object
     
     # add plot code from make_data_vis.R
     # change any placeholder character values to input widgets
     # refer to a reactive plot_data object as plot_data()
 
-    selected_color <- input$plot_color
+    .color <- input$plot_color
     
-    title <- paste0("Average diamond price of colour ", selected_color, " by cut and clarity")
+    title <- glue::glue("Average diamond price of colour {.color} by cut and clarity")
     x_title <- "Average price ($US thousands)"
     y_title <- "Cut"
     
-    plot <- ggplot_hbar_col(data = plot_data(), 
-                            x_var = average_price_thousands, 
-                            y_var = cut, 
-                            col_var = clarity,
-                            text_var = tip_text,
-                            col_labels_ncol = 4,
-                            title = title, 
-                            x_title = x_title, 
-                            y_title = y_title,
-                            isMobile = input$isMobile)
-    
-    
+    plot <- gg_hbar_col(plot_data(), price, cut, clarity, 
+                        text_var = text,
+                        title = title, 
+                        x_title = x_title, 
+                        y_title = y_title,
+                        x_labels = scales::comma_format(),
+                        col_labels = ggplot2::waiver(),
+                        title_wrap = title_wrap,
+                        font_family = "Helvetica", 
+                        mobile = input$isMobile)
+
     return(plot)
-  })
+  }) #%>% 
+    # bindCache(input$plot_color)
   
   output$plot_desktop <- plotly::renderPlotly({ 
     plotly::ggplotly(plot(), tooltip = "text") %>%
       plotly_camera() 
-
-  })
+  }) #%>% 
+    # bindCache(input$plot_color)
   
   output$plot_mobile <- renderPlot({
     plot() 
-  })
+  }) #%>% 
+    # bindCache(input$plot_color)
   
   ### table ###
   
   table_data <- reactive({   
-    ggplot2::diamonds 
+    ggplot2::diamonds %>% 
+      select(carat:price) %>% 
+      janitor::clean_names(case = "sentence")
   })
   
   output$table <- DT::renderDT(
     table_data(), 
     filter = "top",
     rownames = FALSE,
-    options = list(scrollX = TRUE)
+    options = list(pageLength = ifelse(input$isMobile == FALSE, 10, 5), scrollX = TRUE)
   )
   
   ### download ###
