@@ -16,12 +16,15 @@ shinyServer(function(input, output, session) {
       filter(color == .color) %>% 
       mutate(cut = stringr::str_to_sentence(cut)) %>%
       group_by(cut, clarity, .drop = FALSE) %>%
-      summarise(price = mean(price)) %>%
+      summarise(price = round(mean(price), 2)) %>%
       mutate_text(c("cut", "clarity", "price")) 
     
     return(plot_data)
-  }) %>% 
-    bindCache(input$plot_color)
+  }) #%>% 
+    # bindCache()
+  
+  output$plot_data <- DT::renderDT(plot_data(), filter = "top", rownames = FALSE, 
+                                   options = list(pageLength = 5, scrollX = TRUE))
   
   plot <- reactive({ # create a reactive ggplot object
     
@@ -42,23 +45,24 @@ shinyServer(function(input, output, session) {
                         y_title = y_title,
                         x_labels = scales::comma_format(),
                         col_labels = ggplot2::waiver(),
+                        title_wrap = title_wrap,
                         font_family = "Helvetica", 
                         mobile = input$isMobile)
     
     return(plot)
-  }) %>% 
-    bindCache(input$plot_color)
+  }) #%>% 
+    # bindCache(input$plot_color)
   
   output$plot_desktop <- plotly::renderPlotly({ 
     plotly::ggplotly(plot(), tooltip = "text") %>%
       plotly_camera() 
-  }) %>% 
-    bindCache(input$plot_color)
+  }) #%>% 
+    # bindCache(input$plot_color)
   
   output$plot_mobile <- renderPlot({
     plot() 
-  }) %>% 
-    bindCache(input$plot_color)
+  }) #%>% 
+    # bindCache(input$plot_color)
   
   ### map ###
   output$map <- leaflet::renderLeaflet({
@@ -77,16 +81,19 @@ shinyServer(function(input, output, session) {
     }
     
     return(map_data)
-  }) %>% 
-    bindCache(input$map_filter)
-
+  }) #%>% 
+    # bindCache(input$map_filter)
+  
+  output$map_data <- DT::renderDT(sf::st_drop_geometry(map_data()), filter = "top", rownames = FALSE, 
+                                   options = list(pageLength = 5, scrollX = TRUE))
+  
   draw_map <- function() {
     
     # add leaflet code from make_data_vis.R
     # change any placeholder character values to input widgets
     # refer to a reactive map_data object as map_data()
     # use reactive radius for points that get bigger as the user zooms in, if necessary 
-    # reactive_radius <-  case_when(input$map_zoom < 7, 1, ifelse(input$map_zoom < 9, 2, ifelse(input$map_zoom < 12, 3, 4)))  
+    # reactive_size <-  ifelse(input$map_zoom < 6, 1.5, ifelse(input$map_zoom < 7, 2, ifelse(input$map_zoom < 8, 3, 4)))
 
     title <- paste0("Monitored trends, 2008\u201317")
     
@@ -105,24 +112,18 @@ shinyServer(function(input, output, session) {
   ### table ###
   
   table_data <- reactive({    # create a reactive table_data object
-    if(input$table_data == "Diamonds") {
-      ggplot2::diamonds %>% 
-        select(carat:price) %>% 
-        rlang::set_names(~snakecase::to_sentence_case(.))
-    } else if(input$table_data == "Storms") {
-      dplyr::storms %>% 
-        select(name, year, month, day, status, wind, pressure) %>% 
-        rlang::set_names(~snakecase::to_sentence_case(.))
-    }
+    ggplot2::diamonds %>% 
+      select(carat:price) %>% 
+      janitor::clean_names(case = "sentence")
   })
   
   output$table <- DT::renderDT(
-    table_data(),
+    table_data(), 
     filter = "top",
     rownames = FALSE,
     options = list(pageLength = ifelse(input$isMobile == FALSE, 10, 5), scrollX = TRUE)
   )
-  
+
   ### download ###
   
   output$download <- downloadHandler(
