@@ -15,9 +15,9 @@ mobileDetect <-
 
 shinyUI(
   fluidPage(
-    tags$div(tags$br()),
-    downloadButton("download_code", tags$strong("Download code")),
-    tags$div(tags$br()),
+    tags$div(tags$br()), # delete this line 
+    downloadButton("download_code", tags$strong("Download code")),  # delete this line 
+    tags$div(tags$br()),  # delete this line 
     tags$head(includeCSS("www/style.css")),
     tags$head(includeScript("www/js/tag-manager.js")),
     mobileDetect("isMobile"),
@@ -31,7 +31,8 @@ shinyUI(
           sidebarPanel(
             width = 3, 
             # add widgets
-            radioButtons("plot_color", "Colour", color_vector)
+            radioButtons("plot_color", "Colour", color_vector),
+            helpText(glue::glue("Data source: {data_source}"))
           ),
           mainPanel(
             width = 9,
@@ -50,7 +51,8 @@ shinyUI(
                 type = 7,
                 color = "#A8A8A8"
               )
-            )
+            ),
+            DT::DTOutput("plot_data")
           )
         )
       ),
@@ -60,42 +62,49 @@ shinyUI(
         sidebarLayout(
           sidebarPanel(
             width = 3,
-            # add widgets
-            radioButtons("map_metric", "Metric", metric_vector)
+            radioButtons("map_filter", "Filter", c("None", "Improving", "Indeterminate", "Worsening")),
+            helpText(glue::glue("Data source: {data_source}"))
           ),
           mainPanel(width = 9,
                     fluidRow(
-                      shinycssloaders::withSpinner(leaflet::leafletOutput("map"), type = 7, color = "#A8A8A8")
+                      shinycssloaders::withSpinner(leaflet::leafletOutput("map"), type = 7, color = "#A8A8A8"),
+                      DT::DTOutput("map_data")
                     ))
         )
       ),
       tabPanel(
         "Table",
         icon = icon("table", lib = "font-awesome"),
-        # fluidRow(
-        #   shinycssloaders::withSpinner(DT::DTOutput("table"), type = 7, color = "#A8A8A8")
-        # )
-        sidebarLayout( 
-          sidebarPanel(
-            width = 3,
-            radioButtons("table_data", "Dataset", c("Diamonds", "Storms"))
-          ),
-          mainPanel(
-            width = 9,
-            shinycssloaders::withSpinner(DT::DTOutput("table"), type = 7, color = "#A8A8A8")
-          )
+        fluidRow(
+          shinycssloaders::withSpinner(DT::DTOutput("table"), type = 7, color = "#A8A8A8"),
+          helpText(glue::glue("Data source: {data_source}"))
         )
+        # sidebarLayout( #use this if multiple datasets
+        #   sidebarPanel(
+        #     width = 3,
+        #     radioButtons("table_data", "Dataset", c("Diamonds", "Storms")),
+        #     helpText(glue::glue("Data source: {data_source}"))
+        #   ),
+        #   mainPanel(
+        #     width = 9,
+        #     shinycssloaders::withSpinner(DT::DTOutput("table"), type = 7, color = "#A8A8A8")
+        #   )
+        # )
       ),
       tabPanel(
         "Download",
         icon = icon("download", lib = "font-awesome"),
-        fluidRow(downloadButton("download", "Download all data"))
-      ),
-      tabPanel(
-        "About",
-        icon = icon("info-circle", lib = "font-awesome"),
-        fluidRow(includeMarkdown("www/about.Rmd"))
-      )
+        fluidRow(
+          tags$div(tags$br()),
+          downloadButton("download", "Download all data"),
+          tags$div(tags$br()),
+          helpText(glue::glue("Data source: {data_source}"))
+        ))
+      # tabPanel(
+      #   "About",
+      #   icon = icon("info-circle", lib = "font-awesome"),
+      #   fluidRow(includeMarkdown("www/about.Rmd"))
+      # )
     )
   )
 )
